Backend
Bun v1.3.10
Bun Blog0 views
Fixes 155 issues (addressing 642 👍). New native REPL, --compile --target=browser for self-contained HTML, TC39 standard ES decorators, Windows ARM64 support, barrel import optimization, and a faster event loop. structuredClone up to 25x faster for arrays, Buffer.slice() 1.8x faster, path.parse() up to 7x faster, fewer closures in bundled output, and upgraded JavaScriptCore with 168x faster deep rope string slicing. Fixes Python asyncio-based MCP servers breaking with Bun.spawn(), plus numerous bugfixes across Node.js compatibility, bun install, the bundler, shell, and Windows.
Source:https://bun.com/blog/bun-v1.3.10Related posts
![[ANN] PgLoom - Deterministic race-condition model checker on the PostgreSQL wire protocol](https://us1.discourse-cdn.com/flex019/uploads/rust_lang/original/3X/d/c/dc80f49bdcee4484d529dde8b7ec560de189f6d5.gif)
[ANN] PgLoom - Deterministic race-condition model checker on the PostgreSQL wire protocol
0Rust Users Forum
My Docker Image Went From 1.79 GB to 246 MB (4 Steps, Measured)
0dev.to
I POSTed to 137 x402 paid routes. 49 of them returned 404.
0dev.to
41 agents tried to buy from my x402 API and got a 405
0dev.to
Rancher Desktop on Windows: The Complete Zero-License Replacement for Docker Desktop
0dev.to
null and undefined are not the same nothing
0dev.to